@@ -94,39 +94,6 @@ test_that("missing NEE and several id cols", {
   )
 })
 
-test_that("GEP error message for non numeric flux", {
-  campaign <- c(1, 1, 2, 2, 3, 3)
-  turfid <- c("A", "A", "A", "A", "B", "B")
-  type <- c("NEE", "ER", "NEE", "ER", "NEE", "ER")
-  flux <- c(3, "jasdg", 2, "a", 9, 11)
-  datetime <- c(
-    "2024-02-11 10:00:00",
-    "2024-02-11 10:00:10",
-    "2024-02-11 10:00:20",
-    "2024-02-11 10:00:30",
-    "2024-02-11 10:00:40",
-    "2024-02-11 10:00:50"
-  )
-  par <- c(300, 2, 250, 5, 320, 1)
-
-  fluxes <- tibble(
-    campaign,
-    turfid,
-    type,
-    flux,
-    datetime,
-    par
-  )
-
-  expect_error(
-    flux_gep(fluxes,
-      type,
-      datetime,
-      flux,
-      id_cols = c("turfid", "campaign")
-    )
-  )
-})
 
 test_that("option to keep all the cols", {
   test_df <- co2_fluxes |>
